# [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.6 slave-ubuntu64

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Thu Feb 3 00:12:57 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.5 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope 3.4 KGS / Python2.4.6 64bit linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zopetoolkit-py2.6 slave-ubuntu64
    Build: http://dev.thehealthagency.com/buildbot/builders/zopetoolkit-py2.6%20slave-ubuntu64/builds/141

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zopetoolkit-py2.6' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.5 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope 3.4 KGS / Python2.4.6 64bit linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list